// created by proto.sh from proto.lst
class protostr {
public static String tb[]={
"Str",
"Newline",
"Skip",
"Hline",
"Dispolast",
"Label",
"String",
"Checkbox",
"Radio",
"Button",
"Button_xpm",
"Button_xpmf",
"Choice",
"Choice_item",
"List",
"List_item",
"Combo",
"Combo_item",
"Group",
"Form",
"Page",
"Book",
"MainForm",
"End",
"Delete",
"Dump",
"Icon_xpm",
"Xfer_xpm",
"Sidetitle",
"Fill",
"Formbutton",
"Groupfit",
"Setweightlast",
"Richtext",
"Password",
"Buttonfill",
"Enteraction",
"Curfield",
"Version",
"Treemenu",
"Treeelem",
"Clist",
"Clist_item",
"Html",
"Treesub",
"Sheet",
"Sheet_item",
"Textarea",
"Slider",
"Gauge",
"Setval",
"Alive",
"Setcontext",
"Defdc",
"Deffont",
"Defpen",
"Defbrush",
"Drawline",
"Drawrect",
"Drawarc",
"Fillrect",
"Fillarc",
"Menubar",
"Popupmenu",
"Submenu",
"Menuentry",
"Clear",
"Drawclip",
"Setcursor",
"Blit",
"Drawtext",
"Refresh",
"Menutitle",
"Listen",
"Prefsubmenu",
"Show",
"Inputgrid",
"Fillpolygon",
"Splash",
"Hidesplash",
"Deletechild",
};
}
